FoxNews.com - Breaking News | Latest News | Current News
Description: Breaking News, Latest News and Current News from FOXNews.com. Breaking news and video. Latest Current News: U.S., World, Entertainment, Health, Business, Technology, Politics, Sports.
Keywords: news, breaking news, latest news, current news, world news, national news
Date: 2010/11/24

Fox Sites
  Fox News
  Fox Business
  Fox News Radio
  Fox News Latino
  Fox Nation

- Register
- Login

Search Site

TIMESTAMP

On Air Now » Anchors and Reporters »

Previous Slide Next Slide

- ### Special Report

  Bret Baier

  6pet
  Weekdays

- ### Fox Report

  Shepard Smith

  7pet
  Weekdays

- ### The O'Reilly Factor

  Bill O'Reilly

  8pet
  Weekdays

- ### Hannity

  Sean Hannity

  9pet
  Weekdays

- ### On The Record

  Greta Van Susteren

  10pet
  Weekdays

- ### America Live

  Megyn Kelly

  1pet
  Weekdays

- ### America's News HQ

  Shannon Bream, Kelly Wright, Jamie Colby

  12pet
  Weekends

- ### America's Newsroom

  Bill Hemmer
  Martha MacCallum

  9aet
  Weekdays

- ### The Cost of Freedom

  Brenda Buttner
  Neil Cavuto
  David Asman

  10aet
  Saturday

- ### Fox & Friends

  Gretchen Carlson
  Steve Doocy
  Brian Kilmeade

  6aet
  Weekdays

- ### Fox News Sunday

  Chris Wallace

  2pet
  Sunday

- ### Fox News Watch

  Jon Scott

  2:30pet
  Saturday

- ### Geraldo at Large

  Geraldo Rivera

  10pet
  Weekends

- ### Glenn Beck

  Glenn Beck

  5pet
  Weekdays

- ### Happening Now

  Jon Scott
  Jenna Lee

  11aet
  Weekdays

- ### Huckabee

  Mike Huckabee

  8pet
  Saturday

- ### The Journal Editorial Report

  Paul Gigot

  2pet
  Saturday

- ### Red Eye w/ Gutfeld

  Greg Gutfeld

  3aet
  Weekdays

- ### Studio B

  Shepard Smith

  3pet
  Weekdays

- ### War Stories

  Oliver North

  2aet
  Saturday

- ### Your World Cavuto

  Neil Cavuto

  4pet
  Weekdays

- Reuters

  Despite an online call for a 'National Opt Out Day,' most flyers are reportedly going along with full-body scans, as the TSA warns of the impact protests could have on holiday travel. | VIDEO

- TRACK FLIGHT DELAYS | Share Your Stories: Tweet #TSATime | DHS to End Color-Coded Alerts?
- TSA: 'We're Not Perverts' | TSA Spent Millions on Body Scanners, Sparking Competitions
- 'Dexter' Star Welcomes TSA Pat-Downs | HAPPENING NOW: Click to Join Live Town Hall

- ### All 29 Miners Dead After 2nd New Zealand Blast

  'Prolific' explosion deep inside a coal mine erases hopes of rescuing miners caught underground 5 days ago, in a disaster the prime minister calls a national tragedy

- ### U.N. Plan to Deal With
  North Korea? More Aid

  EXCLUSIVE: In the wake of a violent North Korean attack on the South, U.N. Secretary General Ban Ki-Moon is planning to channel new aid and development money to the increasingly dangerous regime

  - U.S. Preps for Joint Exercises With S. Korea | VIDEO |
  - Bodies of 2 Civilians Found
  - OPINION: New Strategy Needed
  - YOU DECIDE: How to Deal With N. Korea?

- ### Black Farmer Payout
  Marred by Fraud?

  A handful of GOP lawmakers warn against Congress' OK for a $1B discrimination settlement that passed the Senate last week, despite concerns the claims process may be rife with bogus applications

  - Jobless at 2-Year Low
  - New Home Sales Drop to 7-Year Low
  - Durable Goods Orders Plummet

- ## Road to Recovery

  ### What's Working

  For Otter Box, a company that specializes in protecting your technological devices, business is booming.

- ## America's Third War

  ### Underground Secrets

  Since 2001, 113 tunnels have been found beneath the border — with a 63 percent increase in just the last two years.

- ## Fox News

  ### Home in Epilepsy Fight

  As David Axelrod's daughter shows improvement, the family of Obama's top adviser finds a way to secure her future.

- ## Entertainment

  ### Holiday Movie Preview

  Reese Witherspoon and Ben Stiller battle Tron, Harry Potter and more for your movie dollars. Who should you go see?

- ## It's Your Money

  ### Earmarks in Bills

  According to an analysis, earmarks account for, at most, about $9B in projects in the fiscal year 2011 spending bills.

Previous Slide Next Slide

Previous Slide Next Slide

ADVERTISEMENT

## Watch Live

- Latest News
- Most Read
- Videos

- Poll: Half of Mexicans Call Drug War a Failure
  - America's Third War: Secret Border Tunnels
- Cops: ‘Ugly Betty’ Actor Killed Mom With Sword
- Weekly Jobless Claims Fall to 2-Year Low
- House Aide Charged in Sex Sting | VIDEO
- New Outrage Over NYC Mosque | VIDEO
  - OPINION: More Than a Matter of Faith
- Dem Could Vote for Boehner as House Speaker
- In Danger? Now You Can Text Details to 911
  - Bill May Give Tech Giants a Big Brother
- Petraeus: U.S. Was Skeptical of Taliban Impostor

- San Francisco Bans Happy Meals With Toys
- Russian Agent: Islamic Charity Funded Terror
- Lawmakers Mull a Ban on Earmarks8 in 10 Say Keeping Bush Tax Cuts a Priority
- Georgia Dad Shot Dead at Son's Preschool
- Conservatives at Odds With Vatican on Condoms
  - Vatican Denounces China for Bishop Ordination
- 'Foxy Knoxy' Appeal Begins in Italy
  - Amanda Knox in Italian Murder Mystery
  - 'Foxy Knoxy' Not Looking So Foxy
- Woman Sentenced to Stoning May Be Spared
- Police Search for Missing Pa. College Student

- Jennifer Grey Named `Dancing' Champ
- 'Ugly Betty' Actor Kills Mother With Sword While Screaming Bible Passages, Cops Say
- U.S. Sends Aircraft Carrier for Joint Exercises With South Korea After Deadly Attack
- 29 miners dead after 2nd blast at New Zealand mine
- Lawmakers Warn $1.2 Billion Payout to Black Farmers Rife With Fraud

- Placards, Kilts Part of Plans for Scanner Protests
- U.N. Secretary General Eyes New Aid, Better PR Campaign, for North Korea
- EXCLUSIVE: 'Basketball Wife' Jen Williams Upset with Erin Barry Over Alleged Relationship With Tony Parker
- San Francisco Bans Happy Meals With Toys
- JOHN STOSSEL: The Lost Lesson of Thanksgiving

- ### Whoopi Goldberg in No Spin Zone

- ### Foreign Powers Testing Obama?

- ### Palin Speaking from the 'Heart'

- ### Happy Thanksgiving, Let Me Pat You Down

- ### China Key to Resolving Korean Crisis?

- ### Beck: 5 Stages of Grief

- ### Is Religious Right Fading Away?

- ### Some American Autoworkers Better Than Others?

## Markets

Get Quote
sponsored by

DJIA

Nasdaq

S&P 500

Latest Market News

- Feds Now Targeting Big Fund Companies
- FDIC Opens Nearly 300 Civil Cases Against Bank
- Cuba a Potential Market for U.S. Agriculture
- Delta to Offer Refunds Over TSA Screening

## Features & Faces

- ### Bristol's DWTS Dreams End

  Voter favorite Bristol Palin comes in third behind actor Kyle Massey and injured 'Dancing With the Stars' winner Jennifer Grey |
  Poll: Did the Right Celeb Win?

- ### What Has 10 Legs...

  This bizarre worm (with up to 10 squid-like limbs) is one of a host of strange discoveries that await scientists in the ocean | Nature's Horror Show

- ### 'Wives' Star Defends Eva

  'Basketball Wives' star Jen Williams 'horrified' to learn of rumors that Tony Parker's alleged other woman is a fellow team wife

- ### Lost Lesson of Thanksgiving

  STOSSEL: Kids are taught about the day when Pilgrims and Indians shared the fruits of the harvest — but the first Thanksgiving in 1623 almost didn't happen

- ### Stars Better With Bangs?

  THEN/NOW: It's the eternal question: 'Would I look better with bangs?' We answer that question for a slew of Hollywood ladies

- ### Get Back in the Game

  Everyone goes through dating dry spells. Discover how to cope and quickly break out of a slump

- ### TSA Tips

  Many Americans are upset about new airport security guidelines. Here's YOUR take on the controversy including suggestions for how security procedures might be improved

## US »

- TSA Director on How Screening Protest Will Affect Travel
- Nuclear plant north of NYC back online
- New York Police Search Wooded Area for Missing College Woman
- Frequent Flyer Urges 'National Opt-Out Day'
- Thanksgiving Travel vs. TSA Screening Controversy

## World »

- Malawi, World Bank commit to $140m education loan
- Appeals court upholds Assange detention order
- Egypt's vote ushered in by crackdown on dissent
- Chinese dissent crackdown shrinks Nobel turnout
- U.S. Stands 'Shoulder to Shoulder' With South Korea

## Politics »

- Obama Pardons America's Luckiest Turkeys
- Military Pegs Hourly Air Force One Cost at $180G, as Obama ...
- Lines Moving Smoothly at Airports as Few Opt for Pat-Down ...
- Sex Sting Sends Shockwaves Throughout Capitol Hill
- Palin's Favorite Things

## Entertainment »

- John Travolta, Kelly Preston Welcome Baby Boy
- 'Dexter' Star Julie Benz Welcomes TSA Pat Downs
- EXCLUSIVE: 'Basketball Wife' Jen Williams Upset with Erin ...
- Jennifer Grey Named `Dancing' Champ
- ABC Reports Voting Problems After 'Dancing' Finale

## Health »

- Holiday Eating Without the Acid Reflux
- How to Break Out of Your Dry Spell
- Tests on Toys Find Few Problems This Season
- School Lunch Programs Might Break Poverty Cycle
- Researchers Uncover HIV, Insulin Resistance Link

## Leisure »

- Husband at War, Air Force Wife Pens Cookbook
- Travel: Belize In 5...
- How to Avoid Bedbugs on Vacation
- Three Great Ways to 'Punch' Up Thanksgiving Dinner
- Review: 2011 Hyundai Equus

## SciTech »

- Intel Plans 1,000-Core Processors -- But How Fast Will They Be?
- Scientists Discover the Bizarre 'Squidworm'
- Give Thanks: Decoded Turkey Genome Could Make Better Birds
- Otter Box Abuse
- Building Protection for Portable Devices

## Opinion »

- JOHN STOSSEL: The Lost Lesson of Thanksgiving
- Why Moses Is the Patron Saint of Thanksgiving
- Why a Pledge to Ban Earmarks Is Already Saving You Big Bucks
- Thanks to the 'Liberal Gene,' I'll Get Through ...
- MICHAEL GOODWIN: Let's Give Thanks for Our Nation

## Sports »

- CUP: Focus - And Pressure - Now On Earnhardt
- Miami Dolphins Players Give Back to the Community
- Animal CSI: Vets learn how to investigate crimes
- CUP: Changes A Necessary Move For Hendrick Motorsports
- Texas' Josh Hamilton Wins AL MVP

## Business »

- Deep in debt? Focus on repayment, not credit scores
- Autonomy: Work On A Specific Acquisition Ongoing
- Indian Regulator Bars Two Sahara Group Cos From Raising Funds
- Axl Rose Sues Activision Over Guns N' Roses Guitar Hero ...
- Nokia Appoints Jerri DeVard Chief Marketing Officer

## IMag »

- How to Decorate a Small Mantle
- Best Holiday Accessories
- 4 Beautiful Holiday Dresses
- How to Use Ivy on Your Mantle
- Make Your Holiday Wreath Stand Out

## On Fox News Channel

- ### Fox News Reporting

  Thursday, Starting at 3p ET: If you missed the first three parts, here's your chance to catch back-to back-to episodes of "The Right, All Along"

- ### Hannity

  Wednesday, 9p/12a ET: George W. Bush and Tony Blair impacted world history. Now, we reveal the political beliefs, controversial decisions, and personal friendship of these extraordinary men on a special 'Hannity!'

## Best Of Fox News Channel

- Prime Time
- Day Time
- Other Programming

- O'Reilly Factor

  ### Talking Points

  Happy Thanksgiving, let me pat you down
  • Whoopi in No Spin Zone

- Hannity

  ### Testing Obama?

  Karl Rove on White House response to Korean crisis

- Greta

  ### 'Mama Grizzly' Growls

  Sarah Palin on her vision of feminism, attacks oh her kids and more!
  • Follow Greta on Twitter

- Fox Report

  ### Prime Mover?

  North Korea's deadly strike comes after Kim Jong Il announced his son will succeed him | Get more Shep

- Special Report

  ### Political Grapevine

  Roland Burris wants another high-profile gig
  • Get more Bret

- Glenn Beck

  ### 5 Stages of Grief

  What stage are you in?
  • Get more Beck

- Fox & Friends

  ### NASCAR's 5-Time Champ

  Jimmie Johnson on 'Fox & Friends'

- America's Newsroom

  ### Safe Harbor

  Misericordia dedicated to helping folks like David Axelrod's daughter

- Happening Now

  ### Not Natalee

  Aruba prosecutors: Jawbone found on beach does not belong to Holloway

- America Live

  ### Jindal vs. Obama

  Louisiana governor claims president told him to drop the criticism

- Studio B

  ### Looking for Answers

  Did teen's mangled body fall from plane?

- Your World

  ### Common Sense

  The world still needs America

- Fox News Sunday

  ### Hillary Clinton

  Secretary of state on foreign policy challenges
  • VIDEO

- Huckabee

  ### Whoopi on Walkout

  'View' co-host addresses controversial episode with O'Reilly

- Journal Editorial Report

  ### Deficit Panel Defense

  Rep. Paul Ryan on what conservative critics are missing
  • VIDEO

- Fox News Watch

  ### Koppel vs. Cable

  Veteran newsman takes shot at cable new

- Cost of Freedom

  ### Forbes on Fox

  4 stocks ready to surprise you with great returns
  • Read the recap

- Red Eye

  ### Secrets From the CIA

  Mike Baker answers viewer questions on 'cool secret agent stuff'

## Do more with fox news

- ### Sections »

  - Home
  - U.S.
  - World
  - Business
  - Politics
  - Entertainment
  - Leisure
  - Health
  - Scitech
  - Opinion
  - Sports
  - Video

- ### Shows »

  - America Live
  - America's News HQ
  - America's Newsroom
  - Cavuto
  - Fox News Sunday
  - Fox & Friends
  - Fox News Watch
  - Fox Report
  - Geraldo at Large
  - Glenn Beck
  - Greta

- ###

  - Hannity
  - Happening Now
  - Huckabee
  - Red Eye w/ Gutfeld
  - Special Report
  - Specials
  - Studio B
  - The Cost of Freedom
  - The Journal Editorial Report
  - The O'Reilly Factor
  - War Stories

- ### Tools »

  - Live Video Player
  - Fox News Toolbar
  - uReport
  - Newsletters & Alerts
  - Mobile
  - RSS
  - Podcasts
  - Radio
  - iPhone
  - Fox News Store

  ### Networks »

  - Facebook
  - Twitter
  - Myspace
  - YouTube

## FEATURED MEDIA

- ### Whoopi Goldberg in No Spin Zone

  'View' co-host discusses walkout seen 'round the world

- ### Obama Pardons America's Luckiest Turkeys

  Presidential reprieves for 'Apple' and 'Cider'

## In The News

- - 1 Jennifer Grey
  - 2 South Korea
  - 3 Tiger Woods
  - 4 Natalee Holloway
  - 5 Bristol Palin
- - 6 John Travolta
  - 7 Kelly Preston
  - 8 War Related Supplemental Spending
  - 9 Movie
  - 10 Conan O'Brien

## Weather

Get Weather

- Today

- Tomorrow

- Day After

## Regional News

Region Select Region

- Sword Used In Woman's Murder
- Man Wins $7 Million At A.C. Slots
- Camera Implanted in NYU Prof's Skull
- Staten Island's Wild Turkeys
- Staff Watches Over Empty Juvenile Hall

- Troops Overseas Remembered on Holidays
- Arizona's Tax Man Resigns
- Medical Issue May Have Led to Crash
- Winter Weather Advisory in Northern AZ
- Red Cross Hope Store Opens Black Friday

- Hurt Homeowner Kills Intruder: Sheriff
- Thanksgiving Forecast: Cold & Windy
- Coach Shoots for Winningest Record
- No Enhanced Security at DFW Just Yet
- Katie Hamilton Was First to Forgive Josh

- Mayor Urges Fliers To Use Body Scanners
- Fliers' Anger at TSA Boils Over
- Storm Brings Snow to SoCal Mountains
- Three Killed in Small Plane Crash
- Boy Falls to Death at Staples Center

- Mayor Urges Fliers To Use Body Scanners
- Fliers' Anger at TSA Boils Over
- Storm Brings Snow to SoCal Mountains
- Three Killed in Small Plane Crash
- Boy Falls to Death at Staples Center

WASHINGTON, DC ORLANDO, FL

## Blogs

- Recent
- On Air
- Live Shots

- Politics

  ### Many Opting Out of "National Opt Out Day"; TSA Warns Of Possible Impact On Holiday Travel

  November 24, 2010 11:45 AM

- Gretawire

  ### Headline of the day.......(I say with some sarcasm)

  November 24, 2010 11:43 AM

- Entertainment

  ### VOTE: Did the right celeb win 'Dancing With the Stars'?

  November 24, 2010 12:01 AM

- Weather

  ### Tornados and Blizzard warnings!

  November 23, 2010 03:14 PM

- GretaWire

  ### Headline of the day.......(I say with some sarcasm)

  November 24, 2010 11:43 AM

- Special Report

  ### Behind the Scenes with Bret

  November 23, 2010 05:08 PM

- Green Room

  ### Toddler Touch Up

  November 21, 2010 08:39 AM

- Happening Now

  ### Today In The Hot Seat - Lou Dobbs

  November 19, 2010 11:35 AM

- Liveshots

  ### Many Opting Out of 'National Opt Out Day'

  November 24, 2010 10:59 AM

- Liveshots

  ### 'Foxy Knoxy' Not Looking So Foxy

  November 24, 2010 10:19 AM

- Liveshots

  ### Israel's Concern Over Tension in Lebanon

  November 24, 2010 07:32 AM

- Liveshots

  ### Under Fire, TSA Gets "Thank You" From DHS

  November 23, 2010 05:33 PM

## Connect With Fox News

### Get Free Breaking News Alerts!

News Alerts
Breaking News Alerts
Business News Alerts
GretaWire
FOX Fan Daily Scoop
Most Popular Business
Today's Top Headlines
Monthly Politics Update
Leisure Ledger
FOX 411

## Invalid email address.

Please click here to try again.